@@ -1,36 +1,45 @@
+from kate_core_plugins import create_submenu
+
+DJ_MENU = create_submenu('Django Templates', 'django-templates', 'edit')
+PY_MENU = create_submenu('Python Templates', 'python-templates', 'edit')
+JS_MENU = create_submenu('Js Templates', 'js-templates', 'edit')
+CH_MENU = create_submenu('Checkers', 'checkers', 'tools')
+PR_MENU = create_submenu('Pretty print', 'pretty-print', 'tools')
+
+
 KATE_ACTIONS = {
     'insertIPDB': {'text': 'ipdb', 'shortcut': 'Ctrl+I',
-                   'menu': 'Edit', 'icon': None},
+                   'menu': PY_MENU, 'icon': None},
     'insertInit': {'text': '__init__', 'shortcut': 'Ctrl+-',
-                   'menu': 'Edit', 'icon': None},
+                   'menu': PY_MENU, 'icon': None},
     'insertSuper': {'text': 'super', 'shortcut': 'Alt+-',
-                    'menu': 'Edit', 'icon': None},
+                    'menu': PY_MENU, 'icon': None},
     'callRecursive': {'text': 'call recursive', 'shortcut': 'Ctrl+Alt+-',
-                    'menu': 'Edit', 'icon': None},
+                    'menu': PY_MENU, 'icon': None},
     'checkAll': {'text': 'Check all', 'shortcut': 'Alt+5',
-                 'menu': 'Edit', 'icon': None},
+                 'menu': CH_MENU, 'icon': None},
     'checkPyflakes': {'text': 'pyflakes', 'shortcut': 'Alt+7',
-                      'menu': 'Edit', 'icon': None},
+                      'menu': CH_MENU, 'icon': None},
     'parseCode': {'text': 'Parse code python', 'shortcut': 'Alt+6',
-                  'menu': 'Edit', 'icon': None},
+                  'menu': CH_MENU, 'icon': None},
     'checkPep8': {'text': 'Pep8', 'shortcut': 'Alt+8',
-                  'menu': 'Edit', 'icon': None},
+                  'menu': CH_MENU, 'icon': None},
     'createForm': {'text': 'Create Django Form', 'shortcut': 'Ctrl+Alt+F',
-                   'menu': 'Edit', 'icon': None},
+                   'menu': DJ_MENU, 'icon': None},
     'createModel': {'text': 'Create Django Model', 'shortcut': 'Ctrl+Alt+M',
-                    'menu': 'Edit', 'icon': None},
+                    'menu': DJ_MENU, 'icon': None},
     'importUrls': {'text': 'Template Django urls', 'shortcut': 'Ctrl+Alt+7',
-                   'menu': 'Edit', 'icon': None},
+                   'menu': DJ_MENU, 'icon': None},
     'importViews': {'text': 'Template import views', 'shortcut': 'Ctrl+Alt+v',
-                    'menu': 'Edit', 'icon': None},
+                    'menu': DJ_MENU, 'icon': None},
     'insertReady': {'text': 'jQuery Ready', 'shortcut': 'Ctrl+J',
-                    'menu': 'Edit', 'icon': None},
+                    'menu': JS_MENU, 'icon': None},
     'checkJslint': {'text': 'JSLint', 'shortcut': 'Alt+J',
-                    'menu': 'Edit', 'icon': None},
+                    'menu': CH_MENU, 'icon': None},
     'togglePrettyJsonFormat': {'text': 'Pretty Json', 'shortcut': 'Ctrl+Alt+J',
-                               'menu': 'Edit', 'icon': None},
+                               'menu': PR_MENU, 'icon': None},
     'togglePrettyXMLFormat': {'text': 'Pretty XML', 'shortcut': 'Ctrl+Alt+X',
-                              'menu': 'Edit', 'icon': None},
+                              'menu': PR_MENU, 'icon': None},
 }
 
 PYTHON_AUTOCOMPLETE_ENABLED = True
@@ -39,6 +48,7 @@ JQUERY_AUTOCOMPLETE_ENABLED = True
 CHECKALL_TO_SAVE = True
 IGNORE_PEP8_ERRORS = []
 
+
 try:
     from kate_settings_local import *
 except ImportError:
