@@ -4,7 +4,7 @@ import kate
 from pyflakes.checker import Checker
 from pyflakes.messages import Message
 
-from kate_settings_plugins import kate_plugins_settings
+from kate_settings_plugins import KATE_ACTIONS
 from pyte_plugins.check_plugins import commons
 from pyte_plugins.check_plugins.check_all_plugins import checkAll
 
@@ -37,13 +37,14 @@ def pyflakes(codeString, filename):
         return w.messages
 
 
-@kate.action(**kate_plugins_settings['checkPyflakes'])
-def checkPyflakes(currentDocument=None, refresh=True, show_popup=True):
+@kate.action(**KATE_ACTIONS['checkPyflakes'])
+def checkPyflakes(currentDocument=None, refresh=True):
     if not commons.canCheckDocument(currentDocument):
         return
     if refresh:
         checkAll(currentDocument, ['checkPyflakes'],
                  exclude_all=not currentDocument)
+    move_cursor = not currentDocument
     currentDocument = currentDocument or kate.activeDocument()
 
     path = unicode(currentDocument.url().path())
@@ -54,8 +55,7 @@ def checkPyflakes(currentDocument=None, refresh=True, show_popup=True):
     errors_to_show = []
 
     if len(errors) == 0:
-        if show_popup:
-            commons.showOk("Pyflakes Ok")
+        commons.showOk("Pyflakes Ok")
         return
 
     # Prepare errors found for painting
@@ -66,5 +66,6 @@ def checkPyflakes(currentDocument=None, refresh=True, show_popup=True):
             "line": error.lineno,
             })
 
-    commons.showErrors('Pyflakes Errors:', errors_to_show, mark_key,
-                       currentDocument, show_popup=show_popup)
+    commons.showErrors('Pyflakes Errors:', errors_to_show,
+                       mark_key, currentDocument,
+                       move_cursor=move_cursor)
